<?php
/**
 *
 * @param $form_fields array, fields to include in attachment form
 * @param $post object, attachment record in database
 * @return $form_fields, modified form fields
 */

function tamarind_attachment_fields_fullscreen_link( $form_fields, $post ) {
	$form_fields['mtheme_attachment_fullscreen_url'] = array(
		'label' => esc_html__('Button Link URL','tamarind'),
		'input' => 'text',
		'value' => get_post_meta( $post->ID, 'mtheme_attachment_fullscreen_url', true ),
		'helps' => esc_html__('For Swiper Slide and Thumbnail Gallery links','tamarind'),
		);

	$form_fields['mtheme_attachment_fullscreen_link'] = array(
		'label' => esc_html__('Button Text','tamarind'),
		'input' => 'text',
		'value' => get_post_meta( $post->ID, 'mtheme_attachment_fullscreen_link', true ),
		'helps' => esc_html__('For Swiper Slide and Thumbnail Gallery Button text','tamarind'),
		);

	$form_fields['mtheme_attachment_purchase_url'] = array(
		'label' => esc_html__('Purchase URL','tamarind'),
		'input' => 'text',
		'value' => get_post_meta( $post->ID, 'mtheme_attachment_purchase_url', true ),
		'helps' => esc_html__('Purchase link.','tamarind'),
		);

	return $form_fields;
}

add_filter( 'attachment_fields_to_edit', 'tamarind_attachment_fields_fullscreen_link', 10, 2 );

/**
 *
 * @param $post array, the post data for database
 * @param $attachment array, attachment fields from $_POST form
 * @return $post array, modified post data
 */

function tamarind_attachment_fields_fullscreen_link_save( $post, $attachment ) {
	if( isset( $attachment['mtheme_attachment_fullscreen_link'] ) )
		update_post_meta( $post['ID'], 'mtheme_attachment_fullscreen_link', $attachment['mtheme_attachment_fullscreen_link'] );

	if( isset( $attachment['mtheme_attachment_fullscreen_url'] ) )
		update_post_meta( $post['ID'], 'mtheme_attachment_fullscreen_url', esc_url( $attachment['mtheme_attachment_fullscreen_url'] ) );

	if( isset( $attachment['mtheme_attachment_purchase_url'] ) )
		update_post_meta( $post['ID'], 'mtheme_attachment_purchase_url', esc_url( $attachment['mtheme_attachment_purchase_url'] ) );

	return $post;
}

add_filter( 'attachment_fields_to_save', 'tamarind_attachment_fields_fullscreen_link_save', 10, 2 );

function tamarind_fullscreen_metadata() {
	// Pull all the Featured into an array
	$bg_slideshow_pages = get_posts('post_type=mtheme_featured&orderby=title&numberposts=-1&order=ASC');

	require_once( get_template_directory() . '/framework/options/google-fonts.php');
	$options_fonts = tamarind_google_fonts();

	if ($bg_slideshow_pages) {
		$options_bgslideshow['none'] = "Not Selected";
		foreach($bg_slideshow_pages as $key => $list) {
			$custom = get_post_custom($list->ID);
			if ( isset($custom["fullscreen_type"][0]) ) { 
				$slideshow_type=$custom["fullscreen_type"][0]; 
			} else {
			$slideshow_type="";
			}
			if ($slideshow_type<>"Fullscreen-Video") {
				$options_bgslideshow[$list->ID] = $list->post_title;
			}
		}
	} else {
		$options_bgslideshow[0]="Featured pages not found.";
	}

	$portfolio_worktypes = get_categories('taxonomy=types&title_li=');
	$len = count($portfolio_worktypes);
	$portfolio_list_options='';
	$count=0;
	foreach($portfolio_worktypes as $key => $list) {
		$count++;	
		if (isSet($list->slug)) {
			if ( $len == $count ) {
					$portfolio_list_options .= $list->slug;
			} else {
				$portfolio_list_options .= $list->slug . ',';
			}
		}
	}

	$mtheme_imagepath =  get_template_directory_uri() . '/framework/options/images/metaboxes/';
	$mtheme_fullscreen_box = array(
		'id' => 'featuredmeta-box',
		'title' => esc_html__('Fullscreen Metabox','tamarind'),
		'page' => 'page',
		'context' => 'normal',
		'priority' => 'high',
		'fields' => array(
			array(
				'name' => esc_html__('Fullscreen Settings','tamarind'),
				'id' => 'pagemeta_page_section_id',
				'type' => 'break',
				'sectiontitle' => esc_html__('Page Settings','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Fullscreen Options','tamarind'),
				'id' => 'pagemeta_sep_page_options',
				'type' => 'seperator',
				),
			array(
				'name' => esc_html__('Add Images','tamarind'),
				'id' => 'pagemeta_image_attachments',
				'std' => esc_html__('Upload Images','tamarind'),
				'type' => 'image_gallery',
				'desc' => '<div class="metabox-note">'.esc_html__('Add images from Media Uploader or by uploading new images.','tamarind').'</div>'
				),
			array(
				'name' => esc_html__('Used as Thumbnail gallery description text','tamarind'),
				'id' => 'pagemeta_thumbnail_desc',
				'heading' => 'subhead',
				'type' => 'textarea',
				'desc' => esc_html__('Description to display in thumbnail gallery.','tamarind'),
				'std' => ''
			),
			array(
				'name' => esc_html__('Page Background color','tamarind'),
				'id' => 'pagemeta_pagebackground_color',
				'type' => 'color',
				'desc' => esc_html__('Page background color','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Display Titles & Description','tamarind'),
				'id' => 'pagemeta_slideshow_titledesc',
				'type' => 'select',
				'std' => 'enable',
				'desc' => esc_html__('Display title and description','tamarind'),
				'options' => array(
					'enable' => esc_html__('Enable','tamarind'),
					'disable' => esc_html__('Disable','tamarind')
					)
				),
			array(
				'name' => esc_html__('Fullscreen Type','tamarind'),
				'id' => 'pagemeta_fullscreen_type',
				'type' => 'image',
				'triggerStatus'=> 'on',
				'std' => 'slideshow',
				'class' => 'page_type',
				'desc' => esc_html__('Fullscreen page type','tamarind'),
				'options' => array(
					'slideshow' => $mtheme_imagepath . 'fullscreen_slideshow.png',
					'splitslider' => $mtheme_imagepath . 'fullscreen_splitslider.png',
					'kenburns' => $mtheme_imagepath . 'fullscreen_kenburns.png',
					'coverphoto' => $mtheme_imagepath . 'fullscreen_coverphoto.png',
					'carousel' => $mtheme_imagepath . 'fullscreen_carousel.png',
					'particles' => $mtheme_imagepath . 'fullscreen_particles.png',
					'video' => $mtheme_imagepath . 'fullscreen_video.png',
					'fotorama' => $mtheme_imagepath . 'fullscreen_fotorama.png',
					'swiperslides' => $mtheme_imagepath . 'fullscreen_swipes.png',
					'portfolioslideshow' => $mtheme_imagepath . 'fullscreen_portfolio_slideshow.png',
					'portfoliocarousel' => $mtheme_imagepath . 'fullscreen_portfoliocarousel.png',
					'revslider' => $mtheme_imagepath . 'fullscreen_revslider.png')
				),
			array(
				'name' => esc_html__('Slideshow Fill/Fit','tamarind'),
				'id' => 'pagemeta_fullscreenslideshow_cover',
				'type' => 'select',
				'std' => 'wave',
				'class' => 'page_type-slideshow page_type-coverphoto page_type-portfolioslideshow page_type-particles page_type-trigger',
				'desc' => esc_html__('Transition type for fullscreen slideshow','tamarind'),
				'options' => array(
					'cover' => esc_attr__('Cover','tamarind'),
					'landscape' => esc_attr__('Landscape Fit','tamarind'),
					'portrait' => esc_attr__('Portrait Fit','tamarind'),
					'always' => esc_attr__('Fit Always','tamarind'),
					)
				),
			array(
				'name' => esc_html__('Slideshow Transition','tamarind'),
				'id' => 'pagemeta_fullscreenslideshow_transition',
				'type' => 'select',
				'std' => 'wave',
				'class' => 'page_type-slideshow page_type-coverphoto page_type-portfolioslideshow page_type-particles page_type-trigger',
				'desc' => esc_html__('Transition type for fullscreen slideshow','tamarind'),
				'options' => array(
					'fade' => esc_attr__('Fade','tamarind'),
					'wave' => esc_attr__('Wave','tamarind'),
					'zoom' => esc_attr__('Zoom','tamarind'),
					)
				),
			array(
				'name' => esc_html__('Portfolio Worktypes ( enter comma seperated slugs )','tamarind') . '<br/><br/><small>' . $portfolio_list_options . '</small>',
				'id' => 'pagemeta_photowall_workstypes',
				'heading' => 'subhead',
				'type' => 'text',
				'std' => '',
				'class' => 'page_type-portfolioslideshow page_type-portfoliocarousel page_type-trigger',
				'desc' => esc_html__('Enter comma seperated slugs. Leave Blank to list all.','tamarind'),
				),
			array(
				'name' => __('Particle Type','tamarind'),
				'id' => 'pagemeta_particle_type',
				'type' => 'select',
				'std' => 'lightbox',
				'class' => 'page_type-particles page_type-trigger',
				'desc' => __('Particle type','tamarind'),
				'options' => array(
					'default' => 'Default',
					'stars' => 'Stars',
					'snow' => 'Snow',
					'grab' => 'Grab',
					'move' => 'Move')
			),
			array(
				'name' => __('Particles / Cover Text Style','tamarind'),
				'id' => 'pagemeta_cover_style',
				'type' => 'image',
				'std' => 'plain',
				'class' => 'page_type-coverphoto page_type-particles page_type-trigger',
				'desc' => __('Cover Text Style','tamarind'),
				'options' => array(
					'plain' => $mtheme_imagepath . 'cover_plain.png',
					'border' => $mtheme_imagepath . 'cover_border.png',
					'fill' => $mtheme_imagepath . 'cover_fill.png',
					'topbottom' => $mtheme_imagepath . 'cover_topbottom.png',
					'underline' => $mtheme_imagepath . 'cover_underline.png')
			),
			array(
				'name' => esc_html__('Coverphoto Text Align','tamarind'),
				'id' => 'pagemeta_coverphoto_textalign',
				'type' => 'select',
				'std' => 'center',
				'class' => 'page_type-coverphoto page_type-particles page_type-trigger',
				'desc' => esc_html__('Coverphoto text align','tamarind'),
				'options' => array(
					'center' => esc_attr__('Center','tamarind'),
					'bottom' => esc_attr__('Bottom','tamarind'),
					)
				),
			array(
				'name' => esc_html__('Fotorama Fill mode','tamarind'),
				'id' => 'pagemeta_fotorama_fill',
				'type' => 'select',
				'std' => 'enable',
				'class' => 'page_type-fotorama page_type-trigger',
				'desc' => esc_html__('Fotorama Fill mode','tamarind'),
				'options' => array(
					'cover' => esc_attr__('Fill','tamarind'),
					'contain' => esc_attr__('Fit','tamarind')
					)
				),
			array(
				'name' => esc_html__('Fotorama Thumbnails','tamarind'),
				'id' => 'pagemeta_fotorama_thumbnails',
				'type' => 'select',
				'std' => 'enable',
				'class' => 'page_type-fotorama page_type-trigger',
				'desc' => esc_html__('Fotorama Thumbnails','tamarind'),
				'options' => array(
					'enable' => esc_attr__('Enable','tamarind'),
					'disable' => esc_attr__('Disable','tamarind')
					)
				),
			array(
				'name' => esc_html__('Revolution Slider','tamarind'),
				'id' => 'pagemeta_revslider',
				'type' => 'select',
				'class' => 'page_type-revslider page_type-trigger',
				'desc' => esc_html__('Display Revolution Slider','tamarind'),
				'options' => tamarind_rev_slider_selectors()
				),
			array(
				'name' => esc_html__('Title Font','tamarind'),
				'id' => 'pagemeta_sep_page_options',
				'type' => 'seperator',
				'class' => 'page_type-slideshow page_type-portfolioslideshow page_type-kenburns page_type-particles page_type-coverphoto page_type-trigger',
				),
			array(
				'name' => esc_html__('Title font','tamarind'),
				'id' => 'pagemeta_fullscreentitlefont_meta',
				'type' => 'fontselector',
				'class' => 'page_type-slideshow page_type-portfolioslideshow page_type-kenburns page_type-particles page_type-coverphoto page_type-trigger',
				'desc' => esc_html__('Slideshow/Static Title Font','tamarind'),
				'options' => $options_fonts
				),

			array(
				'name' => esc_html__('Title font size','tamarind'),
				'id' => 'pagemeta_fullscreentitlesize_meta',
				'type' => 'text',
				'class' => 'mtextfield-small page_type-slideshow page_type-portfolioslideshow page_type-particles page_type-kenburns page_type-coverphoto page_type-trigger',
				'desc' => esc_html__('Slideshow/Static Title size in pixels. Only numerical value eg. 52','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Title line-height','tamarind'),
				'id' => 'pagemeta_fullscreentitlelineheight_meta',
				'type' => 'text',
				'class' => 'mtextfield-small page_type-slideshow page_type-portfolioslideshow page_type-particles page_type-kenburns page_type-coverphoto page_type-trigger',
				'desc' => esc_html__('Slideshow/Static Title letter spacing in pixels. Only numerical value eg. 2','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Title letter-spacing','tamarind'),
				'id' => 'pagemeta_fullscreentitlespacing_meta',
				'type' => 'text',
				'class' => 'mtextfield-small page_type-slideshow page_type-portfolioslideshow page_type-particles page_type-kenburns page_type-coverphoto page_type-trigger',
				'desc' => esc_html__('Slideshow/Static Title line height in pixels. Only numerical value eg. 2','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Fill to activate Static Text','tamarind'),
				'id' => 'pagemeta_sep_page_options',
				'type' => 'seperator',
				'class'=> 'page_type-slideshow page_type-portfolioslideshow page_type-kenburns page_type-particles page_type-coverphoto page_type-trigger',
				),
			array(
				'name' => esc_html__('For Kenburns & Static Slideshow Text','tamarind'),
				'id' => 'pagemeta_static_title',
				'class'=> 'page_type-slideshow page_type-portfolioslideshow page_type-kenburns page_type-particles page_type-coverphoto page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('Static Title','tamarind'),
				'std' => ''
				),
			array(
				'name' => '',
				'id' => 'pagemeta_static_description',
				'heading' => 'subhead',
				'class'=> 'page_type-slideshow page_type-portfolioslideshow page_type-kenburns page_type-particles page_type-coverphoto page_type-trigger',
				'type' => 'textarea',
				'desc' => esc_html__('Static Decription','tamarind'),
				'std' => ''
				),
			array(
				'name' => '',
				'id' => 'pagemeta_static_link_text',
				'heading' => 'subhead',
				'class'=> 'page_type-slideshow page_type-portfolioslideshow page_type-kenburns page_type-particles page_type-coverphoto page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('Static Button Text','tamarind'),
				'std' => ''
				),
			array(
				'name' => '',
				'id' => 'pagemeta_static_url',
				'heading' => 'subhead',
				'class'=> 'page_type-slideshow page_type-portfolioslideshow page_type-kenburns page_type-particles page_type-coverphoto page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('Static Button Link','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Page Settings','tamarind'),
				'id' => 'pagemeta_header_section_id',
				'type' => 'break',
				'sectiontitle' => esc_html__('Header Settings','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Page Settings','tamarind'),
				'id' => 'pagemeta_sep_page_title',
				'type' => 'seperator',
				),
			array(
				'name' => esc_html__('Header Type','tamarind'),
				'id' => 'pagemeta_header_type',
				'type' => 'select',
				'std' => 'enable',
				'desc' => esc_html__('Header Type for Horizontal menu','tamarind'),
				'options' => array(
					'overlay' => esc_attr__('Overlay','tamarind'),
					'default' => esc_attr__('Default','tamarind')
					)
				),
			array(
				'name' => esc_html__('Switch Menu','tamarind'),
				'id' => 'pagemeta_menu_choice',
				'type' => 'select',
				'desc' => esc_html__('Select a different menu for this page','tamarind'),
				'options' => tamarind_generate_menulist()
				),
			array(
				'name' => '',
				'id' => 'pagemeta_page_section_id',
				'type' => 'nobreak',
				'class'=> 'page_type-slideshow page_type-video page_type-particles page_type-kenburns page_type-coverphoto page_type-trigger',
				'sectiontitle' => esc_html__('Audio & Video Settings','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Media Settings','tamarind'),
				'id' => 'pagemeta_sep_page_title',
				'class'=> 'page_type-slideshow page_type-video page_type-particles page_type-kenburns page_type-coverphoto page_type-trigger',
				'type' => 'seperator',
				),
			array(
				'name' => esc_html__('Slideshow Audio files (optional)','tamarind'),
				'id' => 'pagemeta_slideshow_mp3',
				'class'=> 'slideshowaudio page_type-slideshow page_type-particles page_type-kenburns page_type-coverphoto page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('Enter MP3 file path for Slideshow. ( full url )','tamarind'),
				'std' => ''
				),

			array(
				'name' => '',
				'id' => 'pagemeta_slideshow_oga',
				'heading' => 'subhead',
				'class'=> 'slideshowaudio page_type-slideshow page_type-particles page_type-kenburns page_type-coverphoto page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('Enter OGA file path for Slideshow ( full url )','tamarind'),
				'std' => ''
				),

			array(
				'name' => '',
				'id' => 'pagemeta_slideshow_m4a',
				'heading' => 'subhead',
				'class'=> 'slideshowaudio page_type-slideshow page_type-particles page_type-kenburns page_type-coverphoto page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('Enter M4A file path for Slideshow ( full url )','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('Youtube video ID','tamarind'),
				'id' => 'pagemeta_youtubevideo',
				'class'=> 'fullscreenvideo page_type-video page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('Youtube IDs eg: ylLzyHk54Z0. Youtube video IDs can be found at the end of youtube url - http://www.youtube.com/watch?v=ylLzyHk54Z0','tamarind'),
				'std' => ''
				),
			array(
				'name' => esc_html__('HTML5 Video','tamarind'),
				'id' => 'pagemeta_html5_poster',
				'class'=> 'html5video page_type-video page_type-trigger',
				'type' => 'upload',
				'desc' => esc_html__('Poster image','tamarind'),
				'std' => ''
				),
			array(
				'name' => '',
				'id' => 'pagemeta_html5_mp4',
				'heading' => 'subhead',
				'class'=> 'html5video page_type-video page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('MP4 file','tamarind'),
				'std' => ''
				),
			array(
				'name' => '',
				'id' => 'pagemeta_html5_webm',
				'heading' => 'subhead',
				'class'=> 'html5video page_type-video page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('WEBM file','tamarind'),
				'std' => ''
				),
			array(
				'name' => '',
				'id' => 'pagemeta_html5_ogv',
				'heading' => 'subhead',
				'class'=> 'html5video page_type-video page_type-trigger',
				'type' => 'text',
				'desc' => esc_html__('OGV file','tamarind'),
				'std' => ''
				)
		)
);
return $mtheme_fullscreen_box;
}
/*
* Meta options for Portfolio post type
*/
function tamarind_featured_options(){
	$mtheme_fullscreen_box = tamarind_fullscreen_metadata();
	tamarind_generate_metaboxes($mtheme_fullscreen_box, get_the_id() );
}
?>