<?php
/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *  
 */
function tamarind_options() {
	
	// Pull all Google Fonts using API into an array
	//$fontArray = unserialize($fontsSeraliazed);
	$options_fonts = tamarind_google_fonts();
	
	// Pull all the categories into an array
	$options_categories = array(); 
	array_push($options_categories, 'All Categories');
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();
	array_push($options_pages, 'Not Selected'); 
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	if ($options_pages_obj) {
		foreach ($options_pages_obj as $page) {
			$options_pages[$page->ID] = $page->post_title;
		}
	}
	
	// Pull all the Featured into an array
	$featured_pages = get_posts('post_type=mtheme_featured&orderby=title&numberposts=-1&order=ASC');
	if ($featured_pages) {
		foreach($featured_pages as $key => $list) {
			$custom = get_post_custom($list->ID);
			if ( isset($custom['fullscreen_type'][0]) ) { 
				$slideshow_type=' ('.$custom['fullscreen_type'][0].')'; 
			} else {
			$slideshow_type="";
			}
			$options_featured[$list->ID] = $list->post_title . $slideshow_type;
		}
	} else {
		$options_featured[0]='Featured pages not found.';
	}
	
	// Pull all the Featured into an array
	$bg_slideshow_pages = tamarind_get_select_target_options('fullscreen_slideshow_posts');
	
	// Pull all the Portfolio into an array
	$portfolio_pages = get_posts('post_type=mtheme_portfolio&orderby=title&numberposts=-1&order=ASC');
	if ($portfolio_pages) {
		foreach($portfolio_pages as $key => $list) {
			$custom = get_post_custom($list->ID);
			$portfolio_list[$list->ID] = $list->post_title;
		}
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/framework/options/images/';
	$theme_imagepath =  get_template_directory_uri() . '/images/';
	$predefined_background_imagepath =  get_template_directory_uri() . '/images/titlebackgrounds/';
		
	$options = array();
		
$options[] = array( 'name'			=> esc_html__('General', 'tamarind' ),
					'icon'			=> 'fa fa-cog',
					'type'			=> 'heading');

	$options[] = array( 'name' => __('Menu type', 'tamarind' ),
						'desc' => __('Menu type', 'tamarind' ),
						'id' => 'header_menu_type',
						'std' => 'center-logo',
						'type' => 'images',
						'options' => array(
							'center-logo' => $imagepath . 'options/center-logo-menu.png',
							'left-detatched'	=> $imagepath . 'options/left-logo-menu.png',
							'split-menu' => $imagepath . 'options/split-menu.png')
						);

	$options[] = array( 'name'			=> esc_html__('Disable Comments in Pages', 'tamarind' ),
						'desc'			=> esc_html__('Disables comments in pages even if comments are enabled in page settings.', 'tamarind' ),
						'id'			=> 'disable_pagecomments',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Add Facebook Opengraph Meta tags', 'tamarind' ),
						'desc'			=> esc_html__('Adds meta tags to recognize featured image , title and decription used in posts and pages.', 'tamarind' ),
						'id'			=> 'opengraph_status',
						'std'			=> '0',
						'type'			=> 'checkbox');

$options[] = array( 'name'			=> esc_html__('APIs', 'tamarind' ),
					'icon'			=> 'fa fa-cogs',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Google Map API Key. Required to display Google map', 'tamarind' ),
						'desc'			=> esc_html__('Google map now requires an API key to display google maps. How to get a ', 'tamarind') . '<a target="_blank" href="https://developers.google.com/maps/documentation/javascript/get-api-key">Google Map API Key</a>',
						'id'			=> 'googlemap_apikey',
						'std'			=> '',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Instagram Token. Required to display Instagram', 'tamarind' ),
						'desc'			=> esc_html__('The Instagram API requires a Token to display user authenticated photos. How to get ', 'tamarind').'<a target="_blank" href="http://imaginem.co/instagram-token/">Instagram Token</a>',
						'id'			=> 'insta_token',
						'std'			=> '',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name' => esc_html__('Instagram Image limit', 'tamarind' ),
						'desc' => esc_html__('Instagram Image limit', 'tamarind' ),
						'id' => 'insta_image_limit',
						'std' => '20',
						'min' => '1',
						'max' => '20',
						'step' => '0',
						'unit' => 'images',
						'type' => 'text');

	$options[] = array( 'name' => esc_html__('Instagram Transition', 'tamarind' ),
						'desc' => esc_html__('Instagram Transition type', 'tamarind' ),
						'id' => 'insta_transition',
						'std' => 'random',
						'type' => 'select',
						'class' => 'mini',
						'options' => array(
								'false' => 'Disable Slideshow',
								'random' => 'Random',
								'fadeInOut' => 'fadeInOut',
								'slideLeft' => 'slideLeft',
								'slideRight' => 'slideRight',
								'slideTop' => 'slideTop',
								'slideBottom' => 'slideBottom',
								'rotateLeft' => 'rotateLeft',
								'rotateRight' => 'rotateRight',
								'rotateTop' => 'rotateTop',
								'rotateBottom' => 'rotateBottom',
								'scale' => 'scale',
								'rotate3d' => 'rotate3d',
								'rotateLeftScale' => 'rotateLeftScale',
								'rotateRightScale' => 'rotateRightScale',
								'rotateTopScale' => 'rotateTopScale',
								'rotateBottomScale' => 'rotateBottomScale')
						);


$options[] = array( 'name'			=> __('Horizontal Menu Logo', 'tamarind' ),
					'icon'			=> 'fa fa-diamond',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> __('Horizontal Menu Dark Logo', 'tamarind' ),
						'desc'			=> __('Logo for menu.', 'tamarind' ),
						'id'			=> 'main_logo',
						'type'			=> 'upload');

	$options[] = array( 'name'			=> __('Horizontal Menu Bright Logo', 'tamarind' ),
						'desc'			=> __('Logo for menu.', 'tamarind' ),
						'id'			=> 'secondary_logo',
						'type'			=> 'upload');

	$options[] = array( 'name'			=> __('Logo Height', 'tamarind' ),
						'desc'			=> __('Logo Height in pixels. Width will be adjusted with height proportion.', 'tamarind' ),
						'id'			=> 'logo_height',
						'min'			=> '0',
						'max'			=> '2000',
						'step'			=> '0',
						'unit'			=> 'pixels',
						'std'			=> '78',
						'type'			=> 'text');
						
	$options[] = array( 'name'			=> __('Top Space', 'tamarind' ),
						'desc'			=> __('Top spacing for logo', 'tamarind' ),
						'id'			=> 'logo_topmargin',
						'min'			=> '0',
						'max'			=> '200',
						'step'			=> '0',
						'unit'			=> 'pixels',
						'std'			=> '0',
						'type'			=> 'text');

	$options[] = array( 'name'			=> __('Left Space', 'tamarind' ),
						'desc'			=> __('Left spacing for logo ( 0 sets default )', 'tamarind' ),
						'id'			=> 'logo_leftmargin',
						'min'			=> '0',
						'max'			=> '200',
						'step'			=> '0',
						'unit'			=> 'pixels',
						'std'			=> '0',
						'type'			=> 'text');

$options[] = array( 'name'			=> esc_html__('Responsive Logo', 'tamarind' ),
					'icon'			=> 'fa fa-diamond',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Responsive/Mobile Logo', 'tamarind' ),
						'desc'			=> esc_html__('Upload logo for responsive layout.', 'tamarind' ),
						'id'			=> 'responsive_logo',
						'type'			=> 'upload');

	$options[] = array( 'name'			=> esc_html__('Responsive Logo Width', 'tamarind' ),
						'desc'			=> esc_html__('Responsive Logo width in pixels', 'tamarind' ),
						'id'			=> 'responsive_logo_width',
						'min'			=> '0',
						'max'			=> '2000',
						'step'			=> '0',
						'unit'			=> 'pixels',
						'std'			=> '0',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Responsive Logo Top Space', 'tamarind' ),
						'desc'			=> esc_html__('Top spacing for logo ( 0 sets default )', 'tamarind' ),
						'id'			=> 'responsive_logo_topmargin',
						'min'			=> '0',
						'max'			=> '200',
						'step'			=> '0',
						'unit'			=> 'pixels',
						'std'			=> '0',
						'type'			=> 'text');

$options[] = array( 'name'			=> esc_html__('Footer Logo', 'tamarind' ),
					'icon'			=> 'fa fa-diamond',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Footer Logo', 'tamarind' ),
						'desc'			=> esc_html__('Upload logo for footer.', 'tamarind' ),
						'id'			=> 'footer_logo',
						'type'			=> 'upload');

	$options[] = array( 'name'			=> esc_html__('Footer Logo Width', 'tamarind' ),
						'desc'			=> esc_html__('Footer Logo width in pixels', 'tamarind' ),
						'id'			=> 'footer_logo_width',
						'min'			=> '0',
						'max'			=> '2000',
						'step'			=> '0',
						'unit'			=> 'pixels',
						'std'			=> '0',
						'type'			=> 'text');

$options[] = array( 'name'			=> __('Preloader', 'tamarind' ),
					'icon'			=> 'fa fa-refresh',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> __('Preloader Logo', 'tamarind' ),
						'desc'			=> __('Logo for preloader screen.', 'tamarind' ),
						'id'			=> 'preloader_logo',
						'type'			=> 'upload');

	$options[] = array( 'name'			=> esc_html__('Preloader Logo width', 'tamarind' ),
						'desc'			=> esc_html__('Preloader Logo width in pixels', 'tamarind' ),
						'id'			=> 'preloader_logo_width',
						'min'			=> '0',
						'max'			=> '2000',
						'step'			=> '0',
						'unit'			=> 'pixels',
						'std'			=> '0',
						'type'			=> 'text');

		$options[] = array( 'name'			=> __('Preloader color', 'tamarind' ),
							'desc'			=> __('Preloader color', 'tamarind' ),
							'id'			=> 'preloader_color',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Preloader screen color', 'tamarind' ),
							'desc'			=> __('Preloader screen color', 'tamarind' ),
							'id'			=> 'preloader_bgcolor',
							'std'			=> '',
							'type'			=> 'color');

$options[] = array( 'name'			=> esc_html__('Food Menu', 'tamarind' ),
				'icon'			=> 'fa fa-cutlery',
				'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Currency', 'tamarind' ),
						'desc'			=> esc_html__('Currency', 'tamarind' ),
						'id'			=> 'food_currency',
						'std'			=> '$',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Currency Position', 'tamarind' ),
						'desc'			=> esc_html__('Currency Position', 'tamarind' ),
						'id'			=> 'food_currency_position',
						'std'			=> 'left',
						'type' 			=> 'select',
						'class' 		=> 'mini',
						'options' 		=> array(
							'left' 		=> 'Left',
							'right' 	=> 'Right')
						);

	$options[] = array( 'name'			=> esc_html__('Label for Chef Recommended', 'tamarind' ),
						'desc'			=> esc_html__('Label for Chef Recommended', 'tamarind' ),
						'id'			=> 'food_chef_recommended',
						'std'			=> 'Chef Recommended',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Label for New Food', 'tamarind' ),
						'desc'			=> esc_html__('Label for New Food', 'tamarind' ),
						'id'			=> 'food_new_item',
						'std'			=> 'New',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Label for Purchasable/Delivery Food', 'tamarind' ),
						'desc'			=> esc_html__('Label for Purchasable/Delivery Food', 'tamarind' ),
						'id'			=> 'food_order_item',
						'std'			=> 'Order',
						'class'			=> 'tiny',
						'type'			=> 'text');

$options[] = array( 'name'			=> esc_html__('Reservation', 'tamarind' ),
					'icon'			=> 'fa fa-cutlery',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Reservation sub title', 'tamarind' ),
						'desc'			=> esc_html__('Reservation sub title', 'tamarind' ),
						'id'			=> 'reservation_sub_title',
						'std'			=> 'Online',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Reservation title', 'tamarind' ),
						'desc'			=> esc_html__('Reservation title', 'tamarind' ),
						'id'			=> 'reservation_title',
						'std'			=> 'Reservation',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Reservation button text', 'tamarind' ),
						'desc'			=> esc_html__('Reservation button text', 'tamarind' ),
						'id'			=> 'reservation_button_title',
						'std'			=> 'Reservation',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Reservation Slide text', 'tamarind' ),
						'desc'			=> esc_html__('Add text for reservation slide text', 'tamarind' ),
						'id'			=> 'reservation_description',
						'std'			=> 'Integer congue malesuada eros congue varius. Sed malesuada dolor eget velit pretium. Etiam porttitor finibus. Nam suscipit vel ligula at dharetra',
						'type'			=> 'textarea');

	$options[] = array( 'name'			=> esc_html__('Reservation shortcode', 'tamarind' ),
						'desc'			=> esc_html__('Reservation shortcode. For opentable form add ', 'tamarind' ) . '<code>[opentableform]</code>',
						'id'			=> 'reservation_shortcode',
						'std'			=> '',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array(	'name'			=> esc_html__('Prefered reservation page instead of shortcode', 'tamarind' ),
						'desc'			=> esc_html__('Prefered reservation page.', 'tamarind' ),
						'id'			=> 'reservation_page',
						'std'			=> '',
						'type'			=> 'selectyper',
						'class'			=> 'small', //mini, tiny, small
						'options'			=> $options_pages);

$options[] = array( 'name'			=> esc_html__('OpenTable', 'tamarind' ),
					'icon'			=> 'fa fa-cutlery',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('OpenTable ID', 'tamarind' ),
						'desc'			=> esc_html__('OpenTable ID', 'tamarind' ),
						'id'			=> 'opentable_id',
						'std'			=> '',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Person singular referer', 'tamarind' ),
						'desc'			=> esc_html__('Person singular referer. eg: Person', 'tamarind' ),
						'id'			=> 'person_singular',
						'std'			=> 'Person',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Person plural referer', 'tamarind' ),
						'desc'			=> esc_html__('Person plural referer. eg: People', 'tamarind' ),
						'id'			=> 'person_plural',
						'std'			=> 'People',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Button Text', 'tamarind' ),
						'desc'			=> esc_html__('Button Text', 'tamarind' ),
						'id'			=> 'opentable_button_text',
						'std'			=> 'Find a Table',
						'class'			=> 'tiny',
						'type'			=> 'text');

$options[] = array( 'name' => esc_html__('404', 'tamarind' ),
					'icon'			=> 'fa fa-question',
					'type' => 'heading');

		$options[] = array( 'name' => esc_html__('404 Background image ( for page not found. Optional )', 'tamarind' ),
							'desc' => esc_html__('Upload background image', 'tamarind' ),
							'id' => 'general_404_image',
							'type' => 'upload');
						
		$options[] = array( 'name'			=> esc_html__('404 Page title', 'tamarind' ),
						'desc'			=> esc_html__('404 Page not Found!', 'tamarind' ),
						'id'			=> '404_title',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

		$options[] = array( 'name'			=> esc_html__('404 Title color', 'tamarind' ),
							'desc'			=> esc_html__('404 Title color', 'tamarind' ),
							'id'			=> 'text_404_color',
							'std'			=> '',
							'type'			=> 'color');

$options[] = array( 'name'			=> esc_html__('Events', 'tamarind' ),
					'icon'			=> 'fa fa-paper-plane-o',
					'type'			=> 'heading');

	$options[] = array( 'name' => esc_html__('Events Time format', 'tamarind' ),
						'desc' => esc_html__('Events Time format', 'tamarind' ),
						'id' => 'events_time_format',
						'std' => 'true',
						'type' => 'select',
						'class' => 'mini', //mini, tiny, small
						'options' => array(
							'conventional' => 'AM/PM',
							'24hr' => '24 Hrs')
						);

	$options[] = array( 'name'			=> esc_html__('Event gallery title', 'tamarind' ),
						'desc'			=> esc_html__('Event gallery title', 'tamarind' ),
						'id'			=> 'event_gallery_title',
						'std'			=> 'Events',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array(	'name'			=> esc_html__('Prefered events archive page', 'tamarind' ),
						'desc'			=> esc_html__('Prefered events archive page.', 'tamarind' ),
						'id'			=> 'events_archive_page',
						'std'			=> '',
						'type'			=> 'selectyper',
						'class'			=> 'small', //mini, tiny, small
						'options'			=> $options_pages);

	$options[] = array( 'name'			=> esc_html__('Number of thumbnail columns for Events archive listing', 'tamarind' ),
						'desc'			=> esc_html__('Affects events archives. eg. Browsing Events category links.', 'tamarind' ),
						'id'			=> 'event_achivelisting',
						'min'			=> '1',
						'max'			=> '4',
						'step'			=> '0',
						'unit'			=> 'columns',
						'std'			=> '3',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Postponed message', 'tamarind' ),
						'desc'			=> esc_html__('Message for postponed events', 'tamarind' ),
						'id'			=> 'events_postponed_msg',
						'std'			=> 'Event Postponed',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Cancelled message', 'tamarind' ),
						'desc'			=> esc_html__('Message for cancelled events', 'tamarind' ),
						'id'			=> 'events_cancelled_msg',
						'std'			=> 'Event Cancelled',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Event Time Text', 'tamarind' ),
						'desc'			=> esc_html__('Text to use for Event time', 'tamarind' ),
						'id'			=> 'events_time_text',
						'std'			=> 'When',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Event Location Text', 'tamarind' ),
						'desc'			=> esc_html__('Text to use for Event location', 'tamarind' ),
						'id'			=> 'events_location_text',
						'std'			=> 'Where',
						'class'			=> 'tiny',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Event Price Text', 'tamarind' ),
						'desc'			=> esc_html__('Text to use for Event price', 'tamarind' ),
						'id'			=> 'events_price_text',
						'std'			=> 'Cost',
						'class'			=> 'tiny',
						'type'			=> 'text');

$options[] = array( 'name'			=> esc_html__('Blog', 'tamarind' ),
					'icon'			=> 'fa fa-th',
					'type'			=> 'heading');
					
	$options[] = array( 'name'			=> esc_html__('Display Fullpost Archives', 'tamarind' ),
						'desc'			=> esc_html__('Display fullpost archives', 'tamarind' ),
						'id'			=> 'postformat_fullcontent',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Display Author Bio', 'tamarind' ),
						'desc'			=> esc_html__('Display Author Bio', 'tamarind' ),
						'id'			=> 'author_bio',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Read more text', 'tamarind' ),
						'desc'			=> esc_html__('Enter text for Read more', 'tamarind' ),
						'id'			=> 'read_more',
						'std'			=> 'Continue reading',
						'class'			=> 'small',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Blog category listing style', 'tamarind' ),
						'desc'			=> esc_html__('Blog category listing style', 'tamarind' ),
						'id'			=> 'blog_category_style',
						'std' => 'true',
						'type' => 'select',
						'class' => 'mini',
						'options' 	=> array(
							'default'                       => 'Default',
							'grid'                        => 'Grid'
							)
						);

	$options[] = array( 'name'			=> esc_html__('Number of columns for Blog Grid archive style', 'tamarind' ),
						'desc'			=> esc_html__('Number of columns for Blog Grid archive style.', 'tamarind' ),
						'id'			=> 'blog_grid_achivestyle',
						'min'			=> '1',
						'max'			=> '4',
						'step'			=> '0',
						'unit'			=> 'columns',
						'std'			=> '3',
						'type'			=> 'text');

$options[] = array( 'name'			=> esc_html__('Page Title', 'tamarind' ),
					'icon'			=> 'fa fa-header',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Hide Page title', 'tamarind' ),
						'desc'			=> esc_html__('Hide Page title from all pages', 'tamarind' ),
						'id'			=> 'hide_pagetitle',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Page title color', 'tamarind' ),
						'desc'			=> esc_html__('Page title color', 'tamarind' ),
						'id'			=> 'pagetitle_color',
						'std'			=> '',
						'type'			=> 'color');

	$options[] = array( 'name'			=> esc_html__('Page title size', 'tamarind' ),
						'desc'			=> esc_html__('Page title size in pixels. eg. 42', 'tamarind' ),
						'id'			=> 'pagetitle_size',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Page title letter spacing', 'tamarind' ),
						'desc'			=> esc_html__('Page title letter spacing in pixels. eg. 6', 'tamarind' ),
						'id'			=> 'pagetitle_letterspacing',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Page title weight', 'tamarind' ),
						'desc'			=> esc_html__('Page title weight. eg. 100, 200, 300, 400, 500, 600, 700, 800, 900', 'tamarind' ),
						'id'			=> 'pagetitle_weight',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

$options[] = array( 'name'			=> esc_html__('Menu Text', 'tamarind' ),
					'icon'			=> 'fa fa-text-height',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Capitalize Menu', 'tamarind' ),
						'desc'			=> esc_html__('Capitalize Menu', 'tamarind' ),
						'id'			=> 'menu_text_capitalize',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Menu text size', 'tamarind' ),
						'desc'			=> esc_html__('Menu text size. eg. 14', 'tamarind' ),
						'id'			=> 'hmenu_text_size',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Menu text letter spacing', 'tamarind' ),
						'desc'			=> esc_html__('Menu text letter spacing in pixels. eg. 2', 'tamarind' ),
						'id'			=> 'hmenu_text_letterspacing',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Menu text weight', 'tamarind' ),
						'desc'			=> esc_html__('Menu text weight. eg. 100, 200, 300, 400, 500, 600, 700, 800, 900', 'tamarind' ),
						'id'			=> 'hmenu_text_weight',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

	$options[] = array( 'name'			=> __('Horizontal Menu item gap', 'tamarind' ),
						'desc'			=> __('Horizontal Menu item gap. eg. 20', 'tamarind' ),
						'id'			=> 'hmenu_item_gap',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

$options[] = array( 'name'			=> esc_html__('Content Text', 'tamarind' ),
					'icon'			=> 'fa fa-text-height',
					'type'			=> 'heading');

		$options[] = array( 'name'			=> esc_html__('Content Font Size', 'tamarind' ),
						'desc'			=> esc_html__('Contents font size in pixels.', 'tamarind' ),
						'id'			=> 'pagecontent_fontsize',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

		$options[] = array( 'name'			=> esc_html__('Content line height', 'tamarind' ),
						'desc'			=> esc_html__('Contents line height in pixels.', 'tamarind' ),
						'id'			=> 'pagecontent_lineheight',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

		$options[] = array( 'name'			=> esc_html__('Content letter spacing', 'tamarind' ),
						'desc'			=> esc_html__('Content letter spacing in pixels.', 'tamarind' ),
						'id'			=> 'pagecontent_letterspacing',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

		$options[] = array( 'name'			=> esc_html__('Content font weight', 'tamarind' ),
						'desc'			=> esc_html__('Content font weight.(100,200,300,400,500,600,700,800,900)', 'tamarind' ),
						'id'			=> 'pagecontent_fontweight',
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

$options[] = array( 'name'			=> esc_html__('Lightbox', 'tamarind' ),
					'icon'			=> 'fa fa-star',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Disable Lightbox fullscreen button', 'tamarind' ),
						'desc'			=> esc_html__('Disable Lightbox fullscreen', 'tamarind' ),
						'id'			=> 'disable_lightbox_fullscreen',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Disable Lightbox actual size toggle', 'tamarind' ),
						'desc'			=> esc_html__('Disable Lightbox actual size toggle', 'tamarind' ),
						'id'			=> 'disable_lightbox_sizetoggle',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Disable Lightbox download', 'tamarind' ),
						'desc'			=> esc_html__('Disable Lightbox download', 'tamarind' ),
						'id'			=> 'disable_lightbox_download',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Disable Lightbox zoom controls', 'tamarind' ),
						'desc'			=> esc_html__('Disable Lightbox zoom controls', 'tamarind' ),
						'id'			=> 'disable_lightbox_zoomcontrols',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Disable Lightbox autoplay button', 'tamarind' ),
						'desc'			=> esc_html__('Disable Lightbox autoplay button', 'tamarind' ),
						'id'			=> 'disable_lightbox_autoplay',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Disable Lightbox count button', 'tamarind' ),
						'desc'			=> esc_html__('Disable Lightbox count button', 'tamarind' ),
						'id'			=> 'disable_lightbox_count',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Lightbox thumbnails', 'tamarind' ),
						'desc'			=> esc_html__('Lightbox thumbnails', 'tamarind' ),
						'id'			=> 'lightbox_thumbnails_status',
						'std' => 'true',
						'type' => 'select',
						'class' => 'mini',
						'options' 	=> array(
							'disable'                       => 'Disable',
							'enable'                        => 'Enable',
							)
						);

	$options[] = array( 'name' => esc_html__('Lightbox Transition', 'tamarind' ),
						'desc' => esc_html__('Lightbox Transition', 'tamarind' ),
						'id' => 'lightbox_transition',
						'std' => 'lg-slide',
						'type' => 'select',
						'class' => 'mini',
						'options' 	=> array(
							'lg-slide'                       => 'Slide',
							'lg-fade'                        => 'Fade',
							'lg-zoom-in'                     => 'Zoom in',
							'lg-zoom-in-big'                 => 'Zoom in Big', 
							'lg-zoom-out'                    => 'Zoom Out',
							'lg-zoom-out-big'                => 'Zoom Out big', 
							'lg-zoom-out-in'                 => 'Zoom Out in',
							'lg-zoom-in-out'                 => 'Zoom in Out',
							'lg-soft-zoom'                   => 'Soft Zoom', 
							'lg-scale-up'                    => 'Scale Up', 
							'lg-slide-circular'              => 'Slide Circular', 
							'lg-slide-circular-vertical'     => 'Slide Circular vertical', 
							'lg-slide-vertical'              => 'Slide Vertical', 
							'lg-slide-vertical-growth'       => 'Slide Vertical growth', 
							'lg-slide-skew-only'             => 'Slide Skew only', 
							'lg-slide-skew-only-rev'         => 'Slide Skew only reverse',
							'lg-slide-skew-only-y'           => 'Slide Skew only y', 
							'lg-slide-skew-only-y-rev'       => 'Slide Skew only y reverse',
							'lg-slide-skew'                  => 'Slide Skew', 
							'lg-slide-skew-rev'              => 'Slide Skew reverse',
							'lg-slide-skew-cross'            => 'Slide Skew cross', 
							'lg-slide-skew-cross-rev'        => 'Slide Skew cross reverse',
							'lg-slide-skew-ver'              => 'Slide Skew vertically', 
							'lg-slide-skew-ver-rev'          => 'Slide Skew vertically reverse',
							'lg-slide-skew-ver-cross'        => 'Slide Skew vertically cross', 
							'lg-slide-skew-ver-cross-rev'    => 'Slide Skew vertically cross reverse',
							'lg-lollipop'                    => 'Lollipop', 
							'lg-lollipop-rev'                => 'Lollipop reverse',
							'lg-rotate'                      => 'Rotate', 
							'lg-rotate-rev'                  => 'Rotate reverse',
							'lg-tube'                        => 'Tube',
							)
						);

	$options[] = array( 'name'			=> esc_html__('Lightbox Purchase text', 'tamarind' ),
						'desc'			=> esc_html__('Lightbox Purchase text.', 'tamarind' ),
						'id'			=> 'lightbox_purchase_text',
						'std'			=> 'Purchase',
						'class'			=> 'small',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Disable Lightbox title', 'tamarind' ),
						'desc'			=> esc_html__('Disable Lightbox title', 'tamarind' ),
						'id'			=> 'disable_lightbox_title',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name'			=> esc_html__('Lightbox background color', 'tamarind' ),
						'desc'			=> esc_html__('Lightbox background color', 'tamarind' ),
						'id'			=> 'lightbox_bgcolor',
						'std'			=> '',
						'type'			=> 'color');

	$options[] = array( 'name'			=> esc_html__('Lightbox element background color', 'tamarind' ),
						'desc'			=> esc_html__('Lightbox element background color', 'tamarind' ),
						'id'			=> 'lightbox_elementbgcolor',
						'std'			=> '',
						'type'			=> 'color');

	$options[] = array( 'name'			=> esc_html__('Lightbox element color', 'tamarind' ),
						'desc'			=> esc_html__('Lightbox element color', 'tamarind' ),
						'id'			=> 'lightbox_elementcolor',
						'std'			=> '',
						'type'			=> 'color');

$options[] = array( 'name'			=> esc_html__('Sidebars', 'tamarind' ),
					'icon'			=> 'fa fa-newspaper-o',
					'type'			=> 'heading');

	$max_sidebars = tamarind_get_max_sidebars();
	for ($sidebar_count=1; $sidebar_count <= $max_sidebars; $sidebar_count++ ) {

	$options[] = array( 'name'			=> esc_html__('Sidebar ', 'tamarind' ) . $sidebar_count,
							'type'			=> 'info');
						
		$options[] = array( 'name'			=> esc_html__('Sidebar Name', 'tamarind' ),
						'desc'			=> esc_html__('Activate sidebars by naming them.', 'tamarind' ),
						'id'			=> 'mthemesidebar-'.$sidebar_count,
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');

		$options[] = array( 'name'			=> esc_html__('Sidebar Description', 'tamarind' ),
						'desc'			=> esc_html__('A small description to display inside the widget to easily identify it. Widget description is only shown in admin mode inside the widget.', 'tamarind' ),
						'id'			=> 'theme_sidebardesc'.$sidebar_count,
						'std'			=> '',
						'class'			=> 'small',
						'type'			=> 'text');
	}

$options[] = array( 'name'			=> esc_html__('Accent Color', 'tamarind' ),
				'icon'			=> 'fa fa-paint-brush',
				'type'			=> 'heading',
				"subheading"			=> 'header_section_order');

		$options[] = array( 'name'			=> esc_html__('Accent color sitewide', 'tamarind' ),
							'desc'			=> esc_html__('Accent color sitewide', 'tamarind' ),
							'id'			=> 'accent_color',
							'std'			=> '',
							'type'			=> 'color');

$options[] = array( 'name'			=> __('Horizontal Menu Color', 'tamarind' ),
				'icon'			=> 'fa fa-paint-brush',
				'type'			=> 'heading',
				"subheading"			=> 'header_section_order');

		$options[] = array( 'name'			=> __('Menu color', 'tamarind' ),
							'desc'			=> __('Menu color', 'tamarind' ),
							'id'			=> 'menubar_backgroundcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name' => __('Menu bar opacity ( default 80 )', 'tamarind' ),
							'desc' => __('Note: Only applies if a color is set as menu color', 'tamarind' ),
							'id' => 'menubar_backgroundopacity',
							'min' => '0',
							'max' => '100',
							'step' => '0',
							'unit' => '%',
							'std' => '85',
							'type' => 'text');

		$options[] = array( 'name'			=> __('Menu top border color', 'tamarind' ),
							'desc'			=> __('Menu top border color', 'tamarind' ),
							'id'			=> 'menutopbar_color',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Menu link color', 'tamarind' ),
							'desc'			=> __('Menu link color', 'tamarind' ),
							'id'			=> 'menu_linkcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Current menu link color', 'tamarind' ),
							'desc'			=> __('Current menu link color', 'tamarind' ),
							'id'			=> 'currentmenu_linkcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Submenu background color', 'tamarind' ),
							'desc'			=> __('Submenu  background color', 'tamarind' ),
							'id'			=> 'menusubcat_bgcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Submenu link color', 'tamarind' ),
							'desc'			=> __('Submenu link color', 'tamarind' ),
							'id'			=> 'menusubcat_linkcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Submenu link hover color', 'tamarind' ),
							'desc'			=> __('Submenu link hover color', 'tamarind' ),
							'id'			=> 'menusubcat_linkhovercolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Current Submenu link color', 'tamarind' ),
							'desc'			=> __('Current Submenu link color', 'tamarind' ),
							'id'			=> 'currentmenusubcat_linkcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Submenu mega menu headings color', 'tamarind' ),
							'desc'			=> __('Submenu mega menu headings color', 'tamarind' ),
							'id'			=> 'megamenuheading_color',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Reservation button color', 'tamarind' ),
							'desc'			=> __('Reservation button color', 'tamarind' ),
							'id'			=> 'resbutton_color',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Reservation button hover background', 'tamarind' ),
							'desc'			=> __('Reservation button hover background', 'tamarind' ),
							'id'			=> 'resbuttonhover_color',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> __('Reservation button hover text color', 'tamarind' ),
							'desc'			=> __('Reservation button hover text color', 'tamarind' ),
							'id'			=> 'resbuttonhovertext_color',
							'std'			=> '',
							'type'			=> 'color');
		
$options[] = array( 'name'			=> esc_html__('Responsive Menu', 'tamarind' ),
				'icon'			=> 'fa fa-paint-brush',
				'type'			=> 'heading',
				"subheading"			=> 'header_section_order');

		$options[] = array( 'name'			=> esc_html__('Responsive Menu bar color', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Menu bar color', 'tamarind' ),
							'id'			=> 'mobilemenubar_bgcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Responsive Menu toggle background color', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Menu toggle background color', 'tamarind' ),
							'id'			=> 'mobilemenubar_togglebgcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Responsive Menu toggle icon color', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Menu toggle icon color', 'tamarind' ),
							'id'			=> 'mobilemenubar_togglecolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Responsive Menu background color', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Menu background color', 'tamarind' ),
							'id'			=> 'mobilemenu_bgcolor',
							'std'			=> '',
							'type'			=> 'color');

	$options[] = array( 'name'			=> esc_html__('Use an image as Responsive menu background', 'tamarind' ),
						'desc'			=> esc_html__('Use an image as Responsive menu background', 'tamarind' ),
						'id'			=> 'mobilemenu_bgimage',
						'type'			=> 'upload');

		$options[] = array( 'name'			=> esc_html__('Responsive Menu text and icon color', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Menu text and icon color', 'tamarind' ),
							'id'			=> 'mobilemenu_texticons',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Responsive Menu hover color', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Menu hover color', 'tamarind' ),
							'id'			=> 'mobilemenu_hover',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Responsive Opened Menu color', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Opened Menu color', 'tamarind' ),
							'id'			=> 'mobilemenu_active',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Responsive Menu line colors', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Menu line colors', 'tamarind' ),
							'id'			=> 'mobilemenu_linecolors',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Responsive Footer text colors', 'tamarind' ),
							'desc'			=> esc_html__('Responsive Footer text colors', 'tamarind' ),
							'id'			=> 'mobilemenu_footercolors',
							'std'			=> '',
							'type'			=> 'color');

$options[] = array( 'name'				=> esc_html__('Page Color', 'tamarind' ),
					'icon'			=> 'fa fa-paint-brush',
					'type'				=> 'heading',
					"subheading"		=> 'header_section_order');

		$options[] = array( 'name'			=> esc_html__('Page background color', 'tamarind' ),
							'desc'			=> esc_html__('Page background color', 'tamarind' ),
							'id'			=> 'page_bgcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Page contents color', 'tamarind' ),
							'desc'			=> esc_html__('Page contents color', 'tamarind' ),
							'id'			=> 'page_contentscolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Page contents heading color', 'tamarind' ),
							'desc'			=> esc_html__('Page contents heading color', 'tamarind' ),
							'id'			=> 'page_contentsheading',
							'std'			=> '',
							'type'			=> 'color');

$options[] = array( 'name'				=> esc_html__('Sidebar Color', 'tamarind' ),
					'icon'			=> 'fa fa-paint-brush',
					'type'				=> 'heading',
					"subheading"		=> 'header_section_order');

		$options[] = array( 'name'			=> esc_html__('Sidebar heading color', 'tamarind' ),
							'desc'			=> esc_html__('Sidebar heading color', 'tamarind' ),
							'id'			=> 'sidebar_headingcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Sidebar heading underline color', 'tamarind' ),
							'desc'			=> esc_html__('Sidebar heading underline color', 'tamarind' ),
							'id'			=> 'sidebar_headinglinecolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Sidebar link color', 'tamarind' ),
							'desc'			=> esc_html__('Sidebar link color', 'tamarind' ),
							'id'			=> 'sidebar_linkcolor',
							'std'			=> '',
							'type'			=> 'color');

		$options[] = array( 'name'			=> esc_html__('Sidebar text color', 'tamarind' ),
							'desc'			=> esc_html__('Sidebar text color', 'tamarind' ),
							'id'			=> 'sidebar_textcolor',
							'std'			=> '',
							'type'			=> 'color');

	$options[] = array( 'name' => 'Footer Color',
					'icon'			=> 'fa fa-paint-brush',
					'type' => 'heading',
					"subheading" => 'header_section_order');

		$options[] = array( 'name' => 'Footer background',
							'desc' => 'Footer background',
							'id' => 'footer_bgcolor',
							'std' => '',
							'type' => 'color');

	$options[] = array( 'name' => 'Footer heading color',
						'desc' => 'Footer heading color',
						'id' => 'footer_heading',
						'std' => '',
						'type' => 'color');

	$options[] = array( 'name' => 'Footer text color',
						'desc' => 'Footer text color',
						'id' => 'footer_text',
						'std' => '',
						'type' => 'color');

	$options[] = array( 'name' => 'Footer text link color',
						'desc' => 'Footer text link color',
						'id' => 'footer_link',
						'std' => '',
						'type' => 'color');

	$options[] = array( 'name' => 'Footer text link hover color',
						'desc' => 'Footer text link hover color',
						'id' => 'footer_linkhover',
						'std' => '',
						'type' => 'color');

	$options[] = array( 'name' => 'Footer icon color',
						'desc' => 'Footer icon color',
						'id' => 'footer_iconcolor',
						'std' => '',
						'type' => 'color');

						
$options[] = array( 'name'			=> esc_html__('Fonts', 'tamarind' ),
					'icon'			=> 'fa fa-font',
					'type'			=> 'heading');
					
$options[] = array( 'name'			=> esc_html__('Enable Google Web Fonts', 'tamarind' ),
					'desc'			=> esc_html__('Enable Google Web fonts', 'tamarind' ),
					'id'			=> 'default_googlewebfonts',
					'std'			=> '0',
					'type'			=> 'checkbox');

	$options[] = array(	'name'			=> esc_html__('Hero image title', 'tamarind' ),
						'desc'			=> esc_html__('Select font for hero title', 'tamarind' ),
						'id'			=> 'hero_title',
						'std'			=> 'Default Font',
						'type'			=> 'selectgooglefont',
						'class'			=> 'small', //mini, tiny, small
						'options'			=> $options_fonts);	
						
	$options[] = array(	'name'			=> esc_html__('Menu Font', 'tamarind' ),
						'desc'			=> esc_html__('Select menu font', 'tamarind' ),
						'id'			=> 'menu_font',
						'std'			=> '',
						'type'			=> 'selectgooglefont',
						'class'			=> 'small', //mini, tiny, small
						'options'			=> $options_fonts);
						
	$options[] = array(	'name'			=> esc_html__('Heading Font (applies to all headings)', 'tamarind' ),
						'desc'			=> esc_html__('Select heading font', 'tamarind' ),
						'id'			=> 'heading_font',
						'std'			=> '',
						'type'			=> 'selectgooglefont',
						'class'			=> 'small', //mini, tiny, small
						'options'			=> $options_fonts);	
						
	$options[] = array(	'name'			=> esc_html__('Contents', 'tamarind' ),
						'desc'			=> esc_html__('Select font for headings inside posts and pages', 'tamarind' ),
						'id'			=> 'page_contents',
						'std'			=> '',
						'type'			=> 'selectgooglefont',
						'class'			=> 'small', //mini, tiny, small
						'options'			=> $options_fonts);

$options[] = array( 'name'			=> esc_html__('WPML', 'tamarind' ),
					'icon'			=> 'fa fa-globe',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Enable Built-in WPML language selector', 'tamarind' ),
						'desc'			=> esc_html__('Enable Built-in WPML language selector', 'tamarind' ),
						'id'			=> 'wpml_lang_selector_enable',
						'std'			=> '0',
						'type'			=> 'checkbox');

$options[] = array( 'name'			=> esc_html__('WooCommerce', 'tamarind' ),
					'icon'			=> 'fa fa-shopping-cart',
					'type'			=> 'heading');

		$options[] = array( 'name'			=> esc_html__('WooCommerce Shop default title', 'tamarind' ),
						'desc'			=> esc_html__('Shop title for WooCommerce shop. ( default "Shop" ).', 'tamarind' ),
						'id'			=> 'mtheme_woocommerce_shoptitle',
						'std'			=> 'Shop',
						'class'			=> 'small',
						'type'			=> 'text');

	$options[] = array( 'name'			=> esc_html__('Shop Archive with sidebar', 'tamarind' ),
						'desc'			=> esc_html__('Display shop archive with sidebar', 'tamarind' ),
						'id'			=> 'mtheme_wooarchive_sidebar',
						'std'			=> '0',
						'type'			=> 'checkbox');

	$options[] = array( 'name' => esc_html__('Number of Columns', 'tamarind' ),
						'desc' => esc_html__('Number of Columns', 'tamarind' ),
						'id' => 'woocommerce_columns',
						'std' => 'four',
						'type' => 'select',
						'class' => 'mini',
						'options' 	=> array(
							'four'       => 'Four Columns',
							'three'      => 'Three Columns',
							)
						);
						
$options[] = array( 'name'			=> esc_html__('Footer', 'tamarind' ),
					'icon'			=> 'fa fa-arrows-h',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Page footer Copyright text', 'tamarind' ),
						'desc'			=> esc_html__('Enter your copyright and other texts to display in page footer', 'tamarind' ),
						'id'			=> 'footer_copyright',
						'std'			=> 'All rights reserved<br/>Copyright &copy;2018<br/>Photography WordPress',
						'type'			=> 'textarea');

$options[] = array( 'name'			=> esc_html__('Export', 'tamarind' ),
					'icon'			=> 'fa fa-upload',
					'type'			=> 'heading');

	$options[] = array( 'name'			=> esc_html__('Export Options ( Copy this ) Read-Only.', 'tamarind' ),
						'desc'			=> esc_html__('Select All, copy and store your theme options backup. You can use these value to import theme options settings.', 'tamarind' ),
						'id'			=> 'exportpack',
						'std'			=> '',
						'class'			=> 'big',
						'type'			=> 'exporttextarea');

$options[] = array( 'name'			=> esc_html__('Import Options', 'tamarind' ),
					'icon'			=> 'fa fa-download',
					'type'			=> 'heading',
					"subheading"		=> 'exportpack');

	$options[] = array( 'name'			=> esc_html__('Import Options ( Paste and Save )', 'tamarind' ),
						'desc'			=> esc_html__('CAUTION: Copy and Paste the Export Options settings into the window and Save to apply theme options settings.', 'tamarind' ),
						'id'			=> 'importpack',
						'std'			=> '',
						'class'			=> 'big',
						'type'			=> 'importtextarea');

	return $options;
}
?>